@@ -57,10 +57,14 @@ class OAuth1Hook(object):
     :param consumer_secret: Client consumer secret.
     :param access_token: Access token key.
     :param access_token_secret: Access token secret.
-    :param header_auth: Authenication via header, defauls to False.
+    :param header_auth: Authenication via header, defaults to False.
     :param signature: A signature method used to sign request parameters.
         Defaults to None. If None the `HmacSha1Signature` method is used as
         default.
+    :param default_oauth_callback: Defining OAuth callback *is required* (only)
+        when obtaining a request token. If `oauth_callback` is not specified
+        otherwise (in URL query or body data params), `default_oauth_callback`
+        shall be used. In all non-request-token requests it can be left out.
     '''
     OAUTH_VERSION = '1.0'
 
@@ -68,7 +72,8 @@ class OAuth1Hook(object):
     oauth_verifier = None
 
     def __init__(self, consumer_key, consumer_secret, access_token=None,
-            access_token_secret=None, header_auth=False, signature=None):
+                 access_token_secret=None, header_auth=False, signature=None,
+                 default_oauth_callback=None):
         # consumer credentials
         self.consumer_key = consumer_key
         self.consumer_secret = consumer_secret
@@ -85,6 +90,9 @@ class OAuth1Hook(object):
         if signature is not None:
             self.signature = signature
 
+        # 'oauth_callback' is required only on request-token requests
+        self.oauth_callback = default_oauth_callback
+
     def __call__(self, request):
         # this is a workaround for a known bug that will be patched
         if isinstance(request.params, list):
@@ -104,12 +112,12 @@ class OAuth1Hook(object):
 
         # sign and add the signature to the request params
         request.oauth_params['oauth_signature'] = \
-                self.signature.sign(request,
-                                    self.consumer_secret,
-                                    self.access_token_secret)
+            self.signature.sign(request,
+                                self.consumer_secret,
+                                self.access_token_secret)
 
         request.params_and_data['oauth_signature'] = \
-                request.oauth_params['oauth_signature']
+            request.oauth_params['oauth_signature']
 
         if self.header_auth:
             # extract the domain for use as the realm
@@ -117,7 +125,7 @@ class OAuth1Hook(object):
             realm = urlunsplit((scheme, netloc, '/', '', ''))
 
             request.headers['Authorization'] = \
-                    self.auth_header(request.oauth_params, realm=realm)
+                self.auth_header(request.oauth_params, realm=realm)
         elif request.method == 'POST':
             content_type = 'application/x-www-form-urlencoded'
             request.headers['content-type'] = content_type
@@ -142,23 +150,17 @@ class OAuth1Hook(object):
         # special handling if we're handed a string
         if params_is_string:
             params = dict(parse_qsl(request.params))
-        if data_is_string:
-            data = dict(parse_qsl(request.data))
 
         # remove any oauth parameters and set them as attributes
         if oauth_param in params.keys():
             setattr(self, oauth_param, params.pop(oauth_param))
-        if oauth_param in data.keys():
+        if not data_is_string and oauth_param in data.keys():
             setattr(self, oauth_param, data.pop(oauth_param))
 
-        # re-encode the params or data if they were a string, without any oauth
-        # params
+        # re-encode the params if they were a string, without any oauth
         if params_is_string:
             request.params = urlencode(params)
 
-        if data_is_string:
-            request.data = urlencode(data)
-
     @property
     def oauth_params(self):
         '''This method handles generating the necessary URL parameters the
